pub trait ProcessorState { }Expand description
The typestate pattern for the different stages in processing data from the command-line.
pub trait ProcessorState { }The typestate pattern for the different stages in processing data from the command-line.